/*
 * Copyright (C) 2012 The Android Open Source Project
 *
 * Copyright (c) 2011-2012, NVIDIA CORPORATION.  All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef ANDROID_LTR558ALS_H
#define ANDROID_LTR558ALS_H

#include "SensorBase.h"

#define LTR_SENSOR_SYSFS_PATH_NAME "/sys/bus/iio/devices/iio:device0/name"
#define LTR_DEVICE_NAME "ltr558"
#define MAX_SENSOR_PATH_LEN 128
#define MAX_SENSOR_NAME_LEN 32
#define MAX_IIO_DEV 10

#define LTR_558ALS_DEF(HANDLE) {                                    \
    .name = "Lite On Technology Corp LTR-558 Ambient Light Sensor", \
    .vendor = "Lite-On Technology",                                 \
    .version = 1,                                                   \
    .handle = HANDLE,                                               \
    .type = SENSOR_TYPE_LIGHT,                                      \
    .maxRange = 1000.0f,                                            \
    .resolution = 1.0f,                                             \
    .power = 0.09f,                                                 \
    .minDelay = 0,                                                  \
    .fifoReservedEventCount = 0,                                    \
    .fifoMaxEventCount = 0 }

#define LTR_558PS_DEF(HANDLE) {                                     \
    .name = "Lite On Technology Corp LTR-558 Proximity sensor",     \
    .vendor = "Lite-On Technology",                                 \
    .version = 1,                                                   \
    .handle = HANDLE,                                               \
    .type = SENSOR_TYPE_PROXIMITY,                                 \
    .maxRange = 1.0f,                                               \
    .resolution = 1.0f,                                             \
    .power = 0.40f,                                                 \
    .minDelay = 0,                                                  \
    .fifoReservedEventCount = 0,                                    \
    .fifoMaxEventCount = 0 }

#define MAX_POLLING_DELAY 2000000000

class ltr558Light : public SensorBase {
    bool mEnabled;
    bool mHasPendingEvent;
    float mLast_value;
    bool mAlready_warned;
    const char *mSysPath;
    const char *mSysEnablePath;
    int sid;
    int64_t mPollingDelay;
    sensors_event_t mLastns;

public:
            ltr558Light(const char *sysPath, const char *sysEnablePath, int sensor_id);
    virtual ~ltr558Light();
    virtual int readEvents(sensors_event_t* data, int count);
    virtual bool hasPendingEvents() const;
    virtual int enable(int32_t handle, int enabled);
    virtual int setDelay(int32_t handle, int64_t ns);
};

class ltr558Prox : public SensorBase {
    bool mEnabled;
    bool mHasPendingEvent;
    bool mAlready_warned;
    float mLast_value;
    const char *mSysPath;
    const char *mSysEnablePath;
    int sid;
    unsigned int mProximityThreshold;
    int64_t mPollingDelay;
    sensors_event_t mLastns;

public:
            ltr558Prox(const char *sysPath, const char *sysEnablePath,
                       int sensor_id, unsigned int ProxThreshold);
    virtual ~ltr558Prox();
    virtual int readEvents(sensors_event_t* data, int count);
    virtual bool hasPendingEvents() const;
    virtual int enable(int32_t handle, int enabled);
    virtual int setDelay(int32_t handle, int64_t ns);
};

#endif  // ANDROID_LTR558ALS_H

