/*
 * Copyright (c) 2013, NVIDIA CORPORATION. All rights reserved.
 *
 * NVIDIA Corporation and its licensors retain all intellectual property
 * and proprietary rights in and to this software, related documentation
 * and any modifications thereto.  Any use, reproduction, disclosure or
 * distribution of this software and related documentation without an express
 * license agreement from NVIDIA Corporation is strictly prohibited.
 */

#ifndef NVNCT_INCLUDED_H
#define NVNCT_INCLUDED_H

#define NCT_MAGIC_ID       "nVCt" /* 0x7443566E */
#define NCT_MAGIC_ID_LEN   4
#define NCT_PART_NAME      "NCT"

#define NCT_VENDOR_ID      0x955  /* FIXME: TEST */
#define NCT_PRODUCT_ID     0x8000 /* FIXME: TEST */

#define NCT_FORMAT_VERSION    0x00010000 /* 0xABCDabcd (ABCD.abcd) */

#define NCT_ENTRY_OFFSET   0x4000
#define MAX_NCT_ENTRY      512
#define MAX_NCT_DATA_SIZE  1024

typedef enum
{
    NCT_ID_START = 0,
    NCT_ID_SERIAL_NUMBER_0 = NCT_ID_START,
    NCT_ID_WIFI_MAC_ADDR,
    NCT_ID_BT_ADDR,
    NCT_ID_CM_ID,
    NCT_ID_LBH_ID,
    NCT_ID_FACTORY_MODE,
    NCT_ID_RAMDUMP,
    NCT_ID_SERIAL_NUMBER_1,
    NCT_ID_SERIAL_NUMBER_2,
    NCT_ID_SERIAL_NUMBER_3,
    NCT_ID_VENDOR_ID,
    NCT_ID_PRODUCT_ID,
    NCT_ID_SPARE_0,
    NCT_ID_SPARE_1,
    NCT_ID_SPARE_2,
    NCT_ID_TEST,
    NCT_ID_END = NCT_ID_TEST,
    NCT_ID_DISABLED = 0xEEEE,
    NCT_ID_MAX = 0xFFFF
} nct_id_type;

typedef struct
{
    char sn[30];
} nct_serial_number_type;

#define NVIDIA_OUI    0x00044B

typedef struct
{
    unsigned char addr[6];
} nct_wifi_mac_addr_type;

typedef struct
{
    unsigned char addr[6];
} nct_bt_addr_type;

typedef struct
{
    unsigned short id;
} nct_cm_id_type;

typedef struct
{
    unsigned short id;
} nct_lbh_id_type;

typedef struct
{
    unsigned int flag;
} nct_factory_mode_type;

typedef struct
{
    unsigned int flag;
} nct_ramdump_type;

typedef struct
{
    unsigned short id;
} nct_vendor_id_type;

typedef struct
{
    unsigned short id;
} nct_product_id_type;

#if NVOS_IS_WINDOWS
#pragma pack(push, 1)
typedef union
{
    nct_serial_number_type   serial_number_0;
    nct_wifi_mac_addr_type   wifi_mac_addr;
    nct_bt_addr_type         bt_addr;
    nct_cm_id_type           cm_id;
    nct_lbh_id_type          lbh_id;
    nct_factory_mode_type    factory_mode;
    nct_ramdump_type         ramdump;
    nct_serial_number_type   serial_number_1;
    nct_serial_number_type   serial_number_2;
    nct_serial_number_type   serial_number_3;
    nct_vendor_id_type       vendor_id;
    nct_product_id_type      product_id;
    unsigned char            u8data;
    unsigned short           u16data;
    unsigned int             u32data;
    unsigned char            u8[MAX_NCT_DATA_SIZE];
    unsigned short           u16[MAX_NCT_DATA_SIZE/2];
    unsigned int             u32[MAX_NCT_DATA_SIZE/4];
}nct_item_type;
#pragma pack(pop)
#else
typedef union
{
    nct_serial_number_type   serial_number_0;
    nct_wifi_mac_addr_type   wifi_mac_addr;
    nct_bt_addr_type         bt_addr;
    nct_cm_id_type           cm_id;
    nct_lbh_id_type          lbh_id;
    nct_factory_mode_type    factory_mode;
    nct_ramdump_type         ramdump;
    nct_serial_number_type   serial_number_1;
    nct_serial_number_type   serial_number_2;
    nct_serial_number_type   serial_number_3;
    nct_vendor_id_type       vendor_id;
    nct_product_id_type      product_id;
    unsigned char            u8data;
    unsigned short           u16data;
    unsigned int             u32data;
    unsigned char            u8[MAX_NCT_DATA_SIZE];
    unsigned short           u16[MAX_NCT_DATA_SIZE/2];
    unsigned int             u32[MAX_NCT_DATA_SIZE/4];
}__attribute__ ((packed))nct_item_type;
#endif

typedef struct
{
    unsigned int index;
    unsigned int reserved[2];
    nct_item_type data;
    unsigned int checksum;
} nct_entry_type;

typedef struct
{
    unsigned int magicId;
    unsigned int vendorId;
    unsigned int productId;
    unsigned int version;
    unsigned int revision;
} nct_part_head_type;

#endif
